@@ -88,24 +88,25 @@ type externalPull struct {
 
 // An External is an external source.
 type External struct {
-	Type            ExternalType     `json:"type"            toml:"type"            yaml:"type"`
-	Encrypted       bool             `json:"encrypted"       toml:"encrypted"       yaml:"encrypted"`
-	Exact           bool             `json:"exact"           toml:"exact"           yaml:"exact"`
-	Executable      bool             `json:"executable"      toml:"executable"      yaml:"executable"`
-	Private         bool             `json:"private"         toml:"private"         yaml:"private"`
-	ReadOnly        bool             `json:"readonly"        toml:"readonly"        yaml:"readonly"`
-	Checksum        externalChecksum `json:"checksum"        toml:"checksum"        yaml:"checksum"`
-	Clone           externalClone    `json:"clone"           toml:"clone"           yaml:"clone"`
-	Exclude         []string         `json:"exclude"         toml:"exclude"         yaml:"exclude"`
-	Filter          externalFilter   `json:"filter"          toml:"filter"          yaml:"filter"`
-	Format          ArchiveFormat    `json:"format"          toml:"format"          yaml:"format"`
-	Archive         externalArchive  `json:"archive"         toml:"archive"         yaml:"archive"`
-	Include         []string         `json:"include"         toml:"include"         yaml:"include"`
-	ArchivePath     string           `json:"path"            toml:"path"            yaml:"path"`
-	Pull            externalPull     `json:"pull"            toml:"pull"            yaml:"pull"`
-	RefreshPeriod   Duration         `json:"refreshPeriod"   toml:"refreshPeriod"   yaml:"refreshPeriod"`
-	StripComponents int              `json:"stripComponents" toml:"stripComponents" yaml:"stripComponents"`
-	URL             string           `json:"url"             toml:"url"             yaml:"url"`
+	Type            ExternalType      `json:"type"            toml:"type"            yaml:"type"`
+	Encrypted       bool              `json:"encrypted"       toml:"encrypted"       yaml:"encrypted"`
+	Exact           bool              `json:"exact"           toml:"exact"           yaml:"exact"`
+	Executable      bool              `json:"executable"      toml:"executable"      yaml:"executable"`
+	Private         bool              `json:"private"         toml:"private"         yaml:"private"`
+	ReadOnly        bool              `json:"readonly"        toml:"readonly"        yaml:"readonly"`
+	Checksum        externalChecksum  `json:"checksum"        toml:"checksum"        yaml:"checksum"`
+	Clone           externalClone     `json:"clone"           toml:"clone"           yaml:"clone"`
+	Decompress      compressionFormat `json:"decompress"      toml:"decompress"      yaml:"decompress"`
+	Exclude         []string          `json:"exclude"         toml:"exclude"         yaml:"exclude"`
+	Filter          externalFilter    `json:"filter"          toml:"filter"          yaml:"filter"`
+	Format          ArchiveFormat     `json:"format"          toml:"format"          yaml:"format"`
+	Archive         externalArchive   `json:"archive"         toml:"archive"         yaml:"archive"`
+	Include         []string          `json:"include"         toml:"include"         yaml:"include"`
+	ArchivePath     string            `json:"path"            toml:"path"            yaml:"path"`
+	Pull            externalPull      `json:"pull"            toml:"pull"            yaml:"pull"`
+	RefreshPeriod   Duration          `json:"refreshPeriod"   toml:"refreshPeriod"   yaml:"refreshPeriod"`
+	StripComponents int               `json:"stripComponents" toml:"stripComponents" yaml:"stripComponents"`
+	URL             string            `json:"url"             toml:"url"             yaml:"url"`
 	sourceAbsPath   AbsPath
 }
 
@@ -119,6 +120,8 @@ type SourceState struct {
 	sourceDirAbsPath        AbsPath
 	destDirAbsPath          AbsPath
 	cacheDirAbsPath         AbsPath
+	createScriptTempDirOnce sync.Once
+	scriptTempDirAbsPath    AbsPath
 	umask                   fs.FileMode
 	encryption              Encryption
 	ignore                  *patternSet
@@ -230,6 +233,13 @@ func WithReadTemplates(readTemplates bool) SourceStateOption {
 	}
 }
 
+// WithScriptTempDir sets the source directory.
+func WithScriptTempDir(scriptDirAbsPath AbsPath) SourceStateOption {
+	return func(s *SourceState) {
+		s.scriptTempDirAbsPath = scriptDirAbsPath
+	}
+}
+
 // WithSourceDir sets the source directory.
 func WithSourceDir(sourceDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -1685,6 +1695,11 @@ func (s *SourceState) getExternalData(
 		}
 	}
 
+	data, err = decompress(external.Decompress, data)
+	if err != nil {
+		return nil, fmt.Errorf("%s: %w", externalRelPath, err)
+	}
+
 	if external.Filter.Command != "" {
 		cmd := exec.Command(external.Filter.Command, external.Filter.Args...) //nolint:gosec
 		cmd.Stdin = bytes.NewReader(data)
@@ -1820,6 +1835,8 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 ) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		contentsFunc := func() (contents []byte, err error) {
+			// FIXME this should share code with RealSystem.RunScript
+
 			// Read the current contents of the target.
 			var currentContents []byte
 			currentContents, err = destSystem.ReadFile(destAbsPath)
@@ -1880,9 +1897,19 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 				return
 			}
 
+			// Create the script temporary directory, if needed.
+			s.createScriptTempDirOnce.Do(func() {
+				if !s.scriptTempDirAbsPath.Empty() {
+					err = os.MkdirAll(s.scriptTempDirAbsPath.String(), 0o700)
+				}
+			})
+			if err != nil {
+				return
+			}
+
 			// Write the modifier to a temporary file.
 			var tempFile *os.File
-			if tempFile, err = os.CreateTemp("", "*."+fileAttr.TargetName); err != nil {
+			if tempFile, err = os.CreateTemp(s.scriptTempDirAbsPath.String(), "*."+fileAttr.TargetName); err != nil {
 				return
 			}
 			defer chezmoierrors.CombineFunc(&err, func() error {
@@ -1918,7 +1945,7 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 
 // newRemoveTargetStateEntryFunc returns a targetStateEntryFunc that removes a
 // target.
-func (s *SourceState) newRemoveTargetStateEntryFunc(sourceRelPath SourceRelPath, fileAttr FileAttr) targetStateEntryFunc {
+func (s *SourceState) newRemoveTargetStateEntryFunc() targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
 		return &TargetStateRemove{}, nil
 	}
@@ -2037,7 +2064,7 @@ func (s *SourceState) newSourceStateFile(
 			targetStateEntryFunc = s.newModifyTargetStateEntryFunc(sourceRelPath, fileAttr, sourceLazyContents, nil)
 		}
 	case SourceFileTypeRemove:
-		targetStateEntryFunc = s.newRemoveTargetStateEntryFunc(sourceRelPath, fileAttr)
+		targetStateEntryFunc = s.newRemoveTargetStateEntryFunc()
 	case SourceFileTypeScript:
 		// If the script has an extension, determine if it indicates an
 		// interpreter to use.
@@ -2811,14 +2838,14 @@ func (e *External) OriginString() string {
 func canonicalSourceStateEntry(sourceStateEntries []SourceStateEntry) (SourceStateEntry, bool) {
 	// Find all directories to check for equivalence.
 	var firstSourceStateDir *SourceStateDir
-	sourceStateDirs := make([]SourceStateEntry, 0, len(sourceStateEntries))
-	for _, sourceStateEntry := range sourceStateEntries {
+	sourceStateDirs := make([]SourceStateEntry, len(sourceStateEntries))
+	for i, sourceStateEntry := range sourceStateEntries {
 		switch sourceStateEntry := sourceStateEntry.(type) {
 		case *SourceStateDir:
 			firstSourceStateDir = sourceStateEntry
-			sourceStateDirs = append(sourceStateDirs, sourceStateEntry)
+			sourceStateDirs[i] = sourceStateEntry
 		case *SourceStateImplicitDir:
-			sourceStateDirs = append(sourceStateDirs, sourceStateEntry)
+			sourceStateDirs[i] = sourceStateEntry
 		default:
 			return nil, false
 		}
