@@ -16,7 +16,7 @@ func TestIntInputModel(t *testing.T) {
 	}{
 		{
 			name:          "empty_with_default",
-			defaultValue:  newInt64(1),
+			defaultValue:  newValue(int64(1)),
 			input:         "\r",
 			expectedValue: 1,
 		},
@@ -52,11 +52,7 @@ func TestIntInputModel(t *testing.T) {
 		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
-			actualModel := testRunModelWithInput(
-				t,
-				NewIntInputModel("prompt", tc.defaultValue),
-				tc.input,
-			)
+			actualModel := testRunModelWithInput(t, NewIntInputModel("prompt", tc.defaultValue), tc.input)
 			assert.Equal(t, tc.expectedCanceled, actualModel.Canceled())
 			assert.Equal(t, tc.expectedValue, actualModel.Value())
 		})
