@@ -139,6 +139,7 @@ type ConfigFile struct {
 	Keeper            keeperConfig            `json:"keeper"            mapstructure:"keeper"            yaml:"keeper"`
 	Lastpass          lastpassConfig          `json:"lastpass"          mapstructure:"lastpass"          yaml:"lastpass"`
 	Onepassword       onepasswordConfig       `json:"onepassword"       mapstructure:"onepassword"       yaml:"onepassword"`
+	OnepasswordSDK    onepasswordSDKConfig    `json:"onepasswordSDK"    mapstructure:"onepasswordSDK"    yaml:"onepasswordSDK"` //nolint:tagliatelle
 	Pass              passConfig              `json:"pass"              mapstructure:"pass"              yaml:"pass"`
 	Passhole          passholeConfig          `json:"passhole"          mapstructure:"passhole"          yaml:"passhole"`
 	RBW               rbwConfig               `json:"rbw"               mapstructure:"rbw"               yaml:"rbw"`
@@ -407,88 +408,90 @@ func newConfig(options ...configOption) (*Config, error) {
 	// The completion template function is added in persistentPreRunRootE as
 	// it needs a *cobra.Command, which we don't yet have.
 	for key, value := range map[string]any{
-		"awsSecretsManager":           c.awsSecretsManagerTemplateFunc,
-		"awsSecretsManagerRaw":        c.awsSecretsManagerRawTemplateFunc,
-		"azureKeyVault":               c.azureKeyVaultTemplateFunc,
-		"bitwarden":                   c.bitwardenTemplateFunc,
-		"bitwardenAttachment":         c.bitwardenAttachmentTemplateFunc,
-		"bitwardenAttachmentByRef":    c.bitwardenAttachmentByRefTemplateFunc,
-		"bitwardenFields":             c.bitwardenFieldsTemplateFunc,
-		"bitwardenSecrets":            c.bitwardenSecretsTemplateFunc,
-		"comment":                     c.commentTemplateFunc,
-		"dashlaneNote":                c.dashlaneNoteTemplateFunc,
-		"dashlanePassword":            c.dashlanePasswordTemplateFunc,
-		"decrypt":                     c.decryptTemplateFunc,
-		"deleteValueAtPath":           c.deleteValueAtPathTemplateFunc,
-		"doppler":                     c.dopplerTemplateFunc,
-		"dopplerProjectJson":          c.dopplerProjectJSONTemplateFunc,
-		"ejsonDecrypt":                c.ejsonDecryptTemplateFunc,
-		"ejsonDecryptWithKey":         c.ejsonDecryptWithKeyTemplateFunc,
-		"encrypt":                     c.encryptTemplateFunc,
-		"eqFold":                      c.eqFoldTemplateFunc,
-		"findExecutable":              c.findExecutableTemplateFunc,
-		"findOneExecutable":           c.findOneExecutableTemplateFunc,
-		"fromIni":                     c.fromIniTemplateFunc,
-		"fromJson":                    c.fromJsonTemplateFunc,
-		"fromJsonc":                   c.fromJsoncTemplateFunc,
-		"fromToml":                    c.fromTomlTemplateFunc,
-		"fromYaml":                    c.fromYamlTemplateFunc,
-		"gitHubKeys":                  c.gitHubKeysTemplateFunc,
-		"gitHubLatestRelease":         c.gitHubLatestReleaseTemplateFunc,
-		"gitHubLatestReleaseAssetURL": c.gitHubLatestReleaseAssetURLTemplateFunc,
-		"gitHubLatestTag":             c.gitHubLatestTagTemplateFunc,
-		"gitHubReleases":              c.gitHubReleasesTemplateFunc,
-		"gitHubTags":                  c.gitHubTagsTemplateFunc,
-		"glob":                        c.globTemplateFunc,
-		"gopass":                      c.gopassTemplateFunc,
-		"gopassRaw":                   c.gopassRawTemplateFunc,
-		"hcpVaultSecret":              c.hcpVaultSecretTemplateFunc,
-		"hcpVaultSecretJson":          c.hcpVaultSecretJSONTemplateFunc,
-		"hexDecode":                   c.hexDecodeTemplateFunc,
-		"hexEncode":                   c.hexEncodeTemplateFunc,
-		"include":                     c.includeTemplateFunc,
-		"includeTemplate":             c.includeTemplateTemplateFunc,
-		"ioreg":                       c.ioregTemplateFunc,
-		"isExecutable":                c.isExecutableTemplateFunc,
-		"joinPath":                    c.joinPathTemplateFunc,
-		"jq":                          c.jqTemplateFunc,
-		"keepassxc":                   c.keepassxcTemplateFunc,
-		"keepassxcAttachment":         c.keepassxcAttachmentTemplateFunc,
-		"keepassxcAttribute":          c.keepassxcAttributeTemplateFunc,
-		"keeper":                      c.keeperTemplateFunc,
-		"keeperDataFields":            c.keeperDataFieldsTemplateFunc,
-		"keeperFindPassword":          c.keeperFindPasswordTemplateFunc,
-		"keyring":                     c.keyringTemplateFunc,
-		"lastpass":                    c.lastpassTemplateFunc,
-		"lastpassRaw":                 c.lastpassRawTemplateFunc,
-		"lookPath":                    c.lookPathTemplateFunc,
-		"lstat":                       c.lstatTemplateFunc,
-		"mozillaInstallHash":          c.mozillaInstallHashTemplateFunc,
-		"onepassword":                 c.onepasswordTemplateFunc,
-		"onepasswordDetailsFields":    c.onepasswordDetailsFieldsTemplateFunc,
-		"onepasswordDocument":         c.onepasswordDocumentTemplateFunc,
-		"onepasswordItemFields":       c.onepasswordItemFieldsTemplateFunc,
-		"onepasswordRead":             c.onepasswordReadTemplateFunc,
-		"output":                      c.outputTemplateFunc,
-		"pass":                        c.passTemplateFunc,
-		"passFields":                  c.passFieldsTemplateFunc,
-		"passhole":                    c.passholeTemplateFunc,
-		"passRaw":                     c.passRawTemplateFunc,
-		"pruneEmptyDicts":             c.pruneEmptyDictsTemplateFunc,
-		"quoteList":                   c.quoteListTemplateFunc,
-		"rbw":                         c.rbwTemplateFunc,
-		"rbwFields":                   c.rbwFieldsTemplateFunc,
-		"replaceAllRegex":             c.replaceAllRegexTemplateFunc,
-		"secret":                      c.secretTemplateFunc,
-		"secretJSON":                  c.secretJSONTemplateFunc,
-		"setValueAtPath":              c.setValueAtPathTemplateFunc,
-		"splitList":                   c.splitListTemplateFunc,
-		"stat":                        c.statTemplateFunc,
-		"toIni":                       c.toIniTemplateFunc,
-		"toPrettyJson":                c.toPrettyJsonTemplateFunc,
-		"toToml":                      c.toTomlTemplateFunc,
-		"toYaml":                      c.toYamlTemplateFunc,
-		"vault":                       c.vaultTemplateFunc,
+		"awsSecretsManager":            c.awsSecretsManagerTemplateFunc,
+		"awsSecretsManagerRaw":         c.awsSecretsManagerRawTemplateFunc,
+		"azureKeyVault":                c.azureKeyVaultTemplateFunc,
+		"bitwarden":                    c.bitwardenTemplateFunc,
+		"bitwardenAttachment":          c.bitwardenAttachmentTemplateFunc,
+		"bitwardenAttachmentByRef":     c.bitwardenAttachmentByRefTemplateFunc,
+		"bitwardenFields":              c.bitwardenFieldsTemplateFunc,
+		"bitwardenSecrets":             c.bitwardenSecretsTemplateFunc,
+		"comment":                      c.commentTemplateFunc,
+		"dashlaneNote":                 c.dashlaneNoteTemplateFunc,
+		"dashlanePassword":             c.dashlanePasswordTemplateFunc,
+		"decrypt":                      c.decryptTemplateFunc,
+		"deleteValueAtPath":            c.deleteValueAtPathTemplateFunc,
+		"doppler":                      c.dopplerTemplateFunc,
+		"dopplerProjectJson":           c.dopplerProjectJSONTemplateFunc,
+		"ejsonDecrypt":                 c.ejsonDecryptTemplateFunc,
+		"ejsonDecryptWithKey":          c.ejsonDecryptWithKeyTemplateFunc,
+		"encrypt":                      c.encryptTemplateFunc,
+		"eqFold":                       c.eqFoldTemplateFunc,
+		"findExecutable":               c.findExecutableTemplateFunc,
+		"findOneExecutable":            c.findOneExecutableTemplateFunc,
+		"fromIni":                      c.fromIniTemplateFunc,
+		"fromJson":                     c.fromJsonTemplateFunc,
+		"fromJsonc":                    c.fromJsoncTemplateFunc,
+		"fromToml":                     c.fromTomlTemplateFunc,
+		"fromYaml":                     c.fromYamlTemplateFunc,
+		"gitHubKeys":                   c.gitHubKeysTemplateFunc,
+		"gitHubLatestRelease":          c.gitHubLatestReleaseTemplateFunc,
+		"gitHubLatestReleaseAssetURL":  c.gitHubLatestReleaseAssetURLTemplateFunc,
+		"gitHubLatestTag":              c.gitHubLatestTagTemplateFunc,
+		"gitHubReleases":               c.gitHubReleasesTemplateFunc,
+		"gitHubTags":                   c.gitHubTagsTemplateFunc,
+		"glob":                         c.globTemplateFunc,
+		"gopass":                       c.gopassTemplateFunc,
+		"gopassRaw":                    c.gopassRawTemplateFunc,
+		"hcpVaultSecret":               c.hcpVaultSecretTemplateFunc,
+		"hcpVaultSecretJson":           c.hcpVaultSecretJSONTemplateFunc,
+		"hexDecode":                    c.hexDecodeTemplateFunc,
+		"hexEncode":                    c.hexEncodeTemplateFunc,
+		"include":                      c.includeTemplateFunc,
+		"includeTemplate":              c.includeTemplateTemplateFunc,
+		"ioreg":                        c.ioregTemplateFunc,
+		"isExecutable":                 c.isExecutableTemplateFunc,
+		"joinPath":                     c.joinPathTemplateFunc,
+		"jq":                           c.jqTemplateFunc,
+		"keepassxc":                    c.keepassxcTemplateFunc,
+		"keepassxcAttachment":          c.keepassxcAttachmentTemplateFunc,
+		"keepassxcAttribute":           c.keepassxcAttributeTemplateFunc,
+		"keeper":                       c.keeperTemplateFunc,
+		"keeperDataFields":             c.keeperDataFieldsTemplateFunc,
+		"keeperFindPassword":           c.keeperFindPasswordTemplateFunc,
+		"keyring":                      c.keyringTemplateFunc,
+		"lastpass":                     c.lastpassTemplateFunc,
+		"lastpassRaw":                  c.lastpassRawTemplateFunc,
+		"lookPath":                     c.lookPathTemplateFunc,
+		"lstat":                        c.lstatTemplateFunc,
+		"mozillaInstallHash":           c.mozillaInstallHashTemplateFunc,
+		"onepassword":                  c.onepasswordTemplateFunc,
+		"onepasswordDetailsFields":     c.onepasswordDetailsFieldsTemplateFunc,
+		"onepasswordDocument":          c.onepasswordDocumentTemplateFunc,
+		"onepasswordItemFields":        c.onepasswordItemFieldsTemplateFunc,
+		"onepasswordRead":              c.onepasswordReadTemplateFunc,
+		"onepasswordSDKItemsGet":       c.onepasswordSDKItemsGet,
+		"onepasswordSDKSecretsResolve": c.onepasswordSDKSecretsResolve,
+		"output":                       c.outputTemplateFunc,
+		"pass":                         c.passTemplateFunc,
+		"passFields":                   c.passFieldsTemplateFunc,
+		"passhole":                     c.passholeTemplateFunc,
+		"passRaw":                      c.passRawTemplateFunc,
+		"pruneEmptyDicts":              c.pruneEmptyDictsTemplateFunc,
+		"quoteList":                    c.quoteListTemplateFunc,
+		"rbw":                          c.rbwTemplateFunc,
+		"rbwFields":                    c.rbwFieldsTemplateFunc,
+		"replaceAllRegex":              c.replaceAllRegexTemplateFunc,
+		"secret":                       c.secretTemplateFunc,
+		"secretJSON":                   c.secretJSONTemplateFunc,
+		"setValueAtPath":               c.setValueAtPathTemplateFunc,
+		"splitList":                    c.splitListTemplateFunc,
+		"stat":                         c.statTemplateFunc,
+		"toIni":                        c.toIniTemplateFunc,
+		"toPrettyJson":                 c.toPrettyJsonTemplateFunc,
+		"toToml":                       c.toTomlTemplateFunc,
+		"toYaml":                       c.toYamlTemplateFunc,
+		"vault":                        c.vaultTemplateFunc,
 	} {
 		c.addTemplateFunc(key, value)
 	}
@@ -811,8 +814,15 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 // createConfigFile creates a config file using a template and returns its
 // contents.
 func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte, cmd *cobra.Command) ([]byte, error) {
+	// Clone funcMap and restore it after creating the config.
+	// This ensures that the init template functions
+	// are removed before "normal" template parsing.
 	funcMap := make(template.FuncMap)
 	chezmoi.RecursiveMerge(funcMap, c.templateFuncs)
+	defer func() {
+		c.templateFuncs = funcMap
+	}()
+
 	initTemplateFuncs := map[string]any{
 		"exit":             c.exitInitTemplateFunc,
 		"promptBool":       c.promptBoolInteractiveTemplateFunc,
@@ -826,9 +836,9 @@ func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte, cmd *co
 		"stdinIsATTY":      c.stdinIsATTYInitTemplateFunc,
 		"writeToStdout":    c.writeToStdout,
 	}
-	chezmoi.RecursiveMerge(funcMap, initTemplateFuncs)
+	chezmoi.RecursiveMerge(c.templateFuncs, initTemplateFuncs)
 
-	tmpl, err := chezmoi.ParseTemplate(filename.String(), data, funcMap, chezmoi.TemplateOptions{
+	tmpl, err := chezmoi.ParseTemplate(filename.String(), data, c.templateFuncs, chezmoi.TemplateOptions{
 		Options: slices.Clone(c.Template.Options),
 	})
 	if err != nil {
@@ -1321,10 +1331,10 @@ func (c *Config) findConfigTemplate() (*configTemplate, error) {
 	case 1:
 		return configTemplates[0], nil
 	default:
-		sourceAbsPathStrs := make([]string, 0, len(configTemplates))
-		for _, configTemplate := range configTemplates {
+		sourceAbsPathStrs := make([]string, len(configTemplates))
+		for i, configTemplate := range configTemplates {
 			sourceAbsPathStr := configTemplate.sourceAbsPath.String()
-			sourceAbsPathStrs = append(sourceAbsPathStrs, sourceAbsPathStr)
+			sourceAbsPathStrs[i] = sourceAbsPathStr
 		}
 		return nil, fmt.Errorf("multiple config file templates: %s ", englishList(sourceAbsPathStrs))
 	}
@@ -1749,6 +1759,7 @@ func (c *Config) newSourceState(
 		chezmoi.WithLogger(sourceStateLogger),
 		chezmoi.WithMode(c.Mode),
 		chezmoi.WithPriorityTemplateData(c.Data),
+		chezmoi.WithScriptTempDir(c.ScriptTempDir),
 		chezmoi.WithSourceDir(c.SourceDirAbsPath),
 		chezmoi.WithSystem(c.sourceSystem),
 		chezmoi.WithTemplateFuncs(c.templateFuncs),
@@ -2557,7 +2568,7 @@ func (c *Config) targetRelPaths(
 // targetRelPathsBySourcePath returns the target relative paths for each arg in
 // args.
 func (c *Config) targetRelPathsBySourcePath(sourceState *chezmoi.SourceState, args []string) ([]chezmoi.RelPath, error) {
-	targetRelPaths := make([]chezmoi.RelPath, 0, len(args))
+	targetRelPaths := make([]chezmoi.RelPath, len(args))
 	targetRelPathsBySourceRelPath := make(map[chezmoi.RelPath]chezmoi.RelPath)
 	_ = sourceState.ForEach(
 		func(targetRelPath chezmoi.RelPath, sourceStateEntry chezmoi.SourceStateEntry) error {
@@ -2566,7 +2577,7 @@ func (c *Config) targetRelPathsBySourcePath(sourceState *chezmoi.SourceState, ar
 			return nil
 		},
 	)
-	for _, arg := range args {
+	for i, arg := range args {
 		argAbsPath, err := chezmoi.NewAbsPathFromExtPath(arg, c.homeDirAbsPath)
 		if err != nil {
 			return nil, err
@@ -2579,7 +2590,7 @@ func (c *Config) targetRelPathsBySourcePath(sourceState *chezmoi.SourceState, ar
 		if !ok {
 			return nil, fmt.Errorf("%s: not in source state", arg)
 		}
-		targetRelPaths = append(targetRelPaths, targetRelPath)
+		targetRelPaths[i] = targetRelPath
 	}
 	return targetRelPaths, nil
 }
@@ -2764,6 +2775,9 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 			Prompt:  true,
 			Mode:    onepasswordModeAccount,
 		},
+		OnepasswordSDK: onepasswordSDKConfig{
+			TokenEnvVar: "OP_SERVICE_ACCOUNT_TOKEN",
+		},
 		Pass: passConfig{
 			Command: "pass",
 		},
